starfederation.datastar.clojure.api.signals


->patch-signalsclj

(->patch-signals signals opts)
source

add-only-if-missing?clj

(add-only-if-missing? v)
source

get-signalsclj

(get-signals request)

Extract datastar signals from a ring request map.

  • For GET and DELETE requests, returns the signals json string from [:query-params consts/datastar-key]. You need to use some middleware that adds the :query-params key to the request for this function to work properly.
  • For all other HTTP methods, returns the request :body as an InputStream.

(Bring your own json parsing)

Extract datastar signals from a ring request map.

- For GET and DELETE requests, returns the signals json string from
  `[:query-params consts/datastar-key]`. You need to use some middleware
  that adds the `:query-params` key to the request for this function to
  work properly.
- For all other HTTP methods, returns the request `:body` as an
  `InputStream`.

(Bring your own json parsing)
sourceraw docstring

patch-signals!clj

(patch-signals! sse-gen signals-content opts)
source

cljdoc builds & hosts documentation for Clojure/Script libraries