(get-signals request)Extract datastar signals from a ring request map.
[:query-params consts/datastar-key]. You need to use some middleware
that adds the :query-params key to the request for this function to
work properly.:body as an
InputStream.(Bring your own json parsing)
Extract datastar signals from a ring request map. - For GET and DELETE requests, returns the signals json string from `[:query-params consts/datastar-key]`. You need to use some middleware that adds the `:query-params` key to the request for this function to work properly. - For all other HTTP methods, returns the request `:body` as an `InputStream`. (Bring your own json parsing)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |